@@ -10,7 +10,7 @@ if os.path.isdir(DIR):
 
 import unittest
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import RPCProxy, CONTEXT, SOCK, test_view
+from trytond.tests.test_tryton import test_view
 
 
 class CalendarSchedulingTestCase(unittest.TestCase):
@@ -28,12 +28,10 @@ class CalendarSchedulingTestCase(unittest.TestCase):
         self.assertRaises(Exception, test_view('calendar_scheduling'))
 
 def suite():
-    return unittest.TestLoader().loadTestsFromTestCase(
-            CalendarSchedulingTestCase)
+    suite = trytond.tests.test_tryton.suite()
+    suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
+            CalendarSchedulingTestCase))
+    return suite
 
 if __name__ == '__main__':
-    suiteTrytond = trytond.tests.test_tryton.suite()
-    suiteCalendarScheduling = suite()
-    alltests = unittest.TestSuite([suiteTrytond, suiteCalendarScheduling])
-    unittest.TextTestRunner(verbosity=2).run(alltests)
-    SOCK.disconnect()
+    unittest.TextTestRunner(verbosity=2).run(suite())
